#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_4 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .dir import dir as dir_cls
from .average_dp import average_dp as average_dp_cls
from .c_1 import c as c_cls
from .limit_range import limit_range as limit_range_cls
from .v_min import v_min as v_min_cls
from .v_max import v_max as v_max_cls
from .strength import strength as strength_cls
from .profile_dp import profile_dp as profile_dp_cls
from .dp_profile import dp_profile as dp_profile_cls
from .swirl_model import swirl_model as swirl_model_cls
from .fan_vr import fan_vr as fan_vr_cls
from .fr import fr as fr_cls
from .hub import hub as hub_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .profile_vt import profile_vt as profile_vt_cls
from .vt_profile import vt_profile as vt_profile_cls
from .profile_vr import profile_vr as profile_vr_cls
from .vr_profile import vr_profile as vr_profile_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls

class fan_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = ...
    dir: dir_cls = ...
    average_dp: average_dp_cls = ...
    c: c_cls = ...
    limit_range: limit_range_cls = ...
    v_min: v_min_cls = ...
    v_max: v_max_cls = ...
    strength: strength_cls = ...
    profile_dp: profile_dp_cls = ...
    dp_profile: dp_profile_cls = ...
    swirl_model: swirl_model_cls = ...
    fan_vr: fan_vr_cls = ...
    fr: fr_cls = ...
    hub: hub_cls = ...
    axis_origin: axis_origin_cls = ...
    axis_direction: axis_direction_cls = ...
    profile_vt: profile_vt_cls = ...
    vt_profile: vt_profile_cls = ...
    profile_vr: profile_vr_cls = ...
    vr_profile: vr_profile_cls = ...
    swirl_factor: swirl_factor_cls = ...
    dpm_bc_type: dpm_bc_type_cls = ...
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = ...
    reinj_inj: reinj_inj_cls = ...
    dpm_bc_udf: dpm_bc_udf_cls = ...
    new_fan_definition: new_fan_definition_cls = ...
    return_type = ...
