#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .initial_time_steps import initial_time_steps as initial_time_steps_cls
from .initial_outer_iter import initial_outer_iter as initial_outer_iter_cls

class initial_outer_iterations(Group):
    """
    'initial_outer_iterations' child.
    """

    fluent_name = "initial-outer-iterations"

    child_names = \
        ['initial_time_steps', 'initial_outer_iter']

    _child_classes = dict(
        initial_time_steps=initial_time_steps_cls,
        initial_outer_iter=initial_outer_iter_cls,
    )

    return_type = "<object object at 0x7fd82ae39610>"
