#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class time_scale_modification_method(Integer):
    """
    Set time scale modification method [0-time-step, 1-cfl].
    """

    fluent_name = "time-scale-modification-method"

    return_type = "<object object at 0x7fd82ae38ad0>"
