#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class accumulated_mass_fraction(Boolean, AllowedValuesMixin):
    """
    'accumulated_mass_fraction' child.
    """

    fluent_name = "accumulated-mass-fraction?"

    return_type = "<object object at 0x7fb66c2e11c0>"
